import { ButtonHTMLAttributes, FC, useState } from "react";
import { OutlinedButton } from "@src/components/common/buttons/outlinedButton";
import Tippy from "@tippyjs/react";

interface AddProjectButtonProps
  extends ButtonHTMLAttributes<HTMLButtonElement> {
  initialProject: string;
  onProjectChanged: (project: string) => void;
}

export const AddProjectButton: FC<AddProjectButtonProps> = (props) => {
  const [menuIsOpen, setMenuIsOpen] = useState(false);
  const [project, setProject] = useState(props.initialProject);
  return (
    <Tippy
      placement="bottom"
      visible={menuIsOpen}
      onClickOutside={() => {
        setMenuIsOpen(false);
      }}
      delay={0}
      interactive={true}
      duration={0}
      content={
        <div
          className="py-2 px-4 bg-white dark:bg-gray-700 border border-accent-500 rounded-md flex flex-col gap-4"
          tabIndex={0}
        >
          <div>
            <input
              type="text"
              tabIndex={0}
              autoFocus
              value={project}
              className="whitespace-nowrap"
              onChange={(e) => setProject(e.target.value)}
              placeholder="Project"
              onKeyDown={(k) => {
                if (k.key === "Enter") {
                  props.onProjectChanged(project);
                }
              }}
              onBlur={() => {
                props.onProjectChanged(project);
              }}
            />
          </div>
        </div>
      }
    >
      <span>
        <OutlinedButton
          className="whitespace-nowrap"
          onClick={() => setMenuIsOpen(true)}
        >
          {props.children || "Add project"}
        </OutlinedButton>
      </span>
    </Tippy>
  );
};
